@@ -1,6 +1,6 @@
 ;;; ef-autumn-theme.el --- Legible dark theme with warm, varied colors (red, yellow, green, teal) -*- lexical-binding:t -*-
 
-;; Copyright (C) 2022  Free Software Foundation, Inc.
+;; Copyright (C) 2022-2023  Free Software Foundation, Inc.
 
 ;; Author: Protesilaos Stavrou <info@protesilaos.com>
 ;; Maintainer: Ef-Themes Development <~protesilaos/ef-themes@lists.sr.ht>
@@ -37,25 +37,29 @@
 (eval-and-compile
   (require 'ef-themes)
 
-  (deftheme ef-autumn "Legible dark theme with warm, varied colors (red, yellow, green, teal).")
+  (deftheme ef-autumn
+    "Legible dark theme with warm, varied colors (red, yellow, green, teal).")
 
   (defconst ef-autumn-palette
-    '(;; Basic tones
+    '(
+;;; Basic values
+
       (bg-main     "#0f0e06")
       (fg-main     "#cfbcba")
-      (bg-dim      "#1f1b19")
+      (bg-dim      "#26211d")
       (fg-dim      "#887c8a")
       (bg-alt      "#36322f")
       (fg-alt      "#70a89f")
 
-      (bg-active   "#46423f")
-      (bg-inactive "#14130a")
+      (bg-active   "#56524f")
+      (bg-inactive "#15140d")
+
+;;; Basic hues for foreground values
 
-      ;; Basic hues for foreground values
       (red             "#ef656a")
       (red-warmer      "#f06a3f")
       (red-cooler      "#ff7a7f")
-      (red-faint       "#d08f72")
+      (red-faint       "#df7f7f")
       (green           "#2fa526")
       (green-warmer    "#64aa0f")
       (green-cooler    "#00b066")
@@ -77,7 +81,8 @@
       (cyan-cooler     "#3dbbb0")
       (cyan-faint      "#82a0af")
 
-      ;; Basic hues for background values
+;;; Basic hues for background values
+
       (bg-red      "#cd2f30")
       (bg-green    "#20a020")
       (bg-yellow   "#9a4f20")
@@ -92,20 +97,25 @@
       (bg-magenta-subtle  "#611062")
       (bg-cyan-subtle     "#004065")
 
-      ;; Diffs
-      (bg-added          "#172c0f")
-      (bg-added-faint    "#0a1f00")
-      (bg-added-refine   "#203f10")
+;;; Diffs
 
-      (bg-changed        "#323200")
-      (bg-changed-faint  "#281a00")
-      (bg-changed-refine "#484800")
+      (bg-added          "#17360f")
+      (bg-added-faint    "#0a2900")
+      (bg-added-refine   "#204810")
+      (fg-added          "#a0e0a0")
 
-      (bg-removed        "#46120a")
-      (bg-removed-faint  "#330a00")
-      (bg-removed-refine "#6a1a16")
+      (bg-changed        "#363300")
+      (bg-changed-faint  "#2a1f00")
+      (bg-changed-refine "#4a4a00")
+      (fg-changed        "#efef80")
+
+      (bg-removed        "#4b120a")
+      (bg-removed-faint  "#3a0a00")
+      (bg-removed-refine "#6f1a16")
+      (fg-removed        "#ffbfbf")
+
+;;; Graphs
 
-      ;; Graphs
       (red-graph-0-bg     "#b52c2c")
       (red-graph-1-bg     "#702020")
       (green-graph-0-bg   "#4fd100")
@@ -119,20 +129,22 @@
       (cyan-graph-0-bg    "#47dfea")
       (cyan-graph-1-bg    "#00808f")
 
-      ;; Special hues
-      (bg-mode-line  "#692a12") (fg-mode-line  "#feeeca")
-      (bg-accent     "#ffa200") (fg-accent     "#000000")
-      (bg-completion "#36213a")
-      (bg-hover      "#265f4a")
-      (bg-hover-alt  "#55345a")
-      (bg-hl-line    "#302a3a")
-      (bg-region     "#3f1020")
-      (bg-paren      "#2f6c4a")
-      (bg-err        "#361400") ; check with err
-      (bg-warning    "#332800") ; check with warning
-      (bg-info       "#152800") ; check with info
+;;; Special hues
 
-      (border        "#4f4945")
+      (bg-mode-line       "#692a12")
+      (fg-mode-line       "#feeeca")
+      (bg-accent          "#ffa200")
+      (bg-completion      "#36213a")
+      (bg-hover           "#265f4a")
+      (bg-hover-secondary "#55345a")
+      (bg-hl-line         "#302a3a")
+      (bg-region          "#3f1020")
+      (bg-paren           "#2f6c4a")
+      (bg-err             "#391400") ; check with err
+      (bg-warning         "#332800") ; check with warning
+      (bg-info            "#152a00") ; check with info
+
+      (border        "#58514f")
       (cursor        "#ffaa33")
       (fg-intense    "#ffffff")
 
@@ -140,22 +152,31 @@
       (modeline-warning "#dfcf33")
       (modeline-info    "#4fdf5f")
 
-      (underline-err     "#ff2f2f")
-      (underline-warning "#e0df00")
-      (underline-info    "#22ff52")
+      (underline-err     "#df2f2f")
+      (underline-warning "#c0b000")
+      (underline-info    "#22b022")
+
+;;; Conditional hues
+
+      (bg-region-intense "#4f4400")
+
+;;; Mappings
+
+;;;; General mappings
 
-      ;; Mappings
       (err red-warmer)
-      (warning yellow-warmer)
+      (warning yellow)
       (info green-cooler)
 
       (link yellow)
       (link-alt cyan-cooler)
-      (date yellow-cooler)
       (name green-warmer)
       (keybind red-warmer)
+      (identifier magenta-faint)
       (prompt cyan-cooler)
 
+;;;; Code mappings
+
       (builtin red-cooler)
       (comment yellow-faint)
       (constant green-warmer)
@@ -166,21 +187,51 @@
       (string red-warmer)
       (type green)
       (variable cyan-warmer)
-
       (rx-escape green-cooler) ; compare with `string'
       (rx-construct magenta-cooler)
 
+;;;; Accent mappings
+
       (accent-0 green-cooler)
       (accent-1 yellow-warmer)
       (accent-2 cyan-cooler)
       (accent-3 magenta-cooler)
 
-      (mail-0 yellow-warmer)
-      (mail-1 green-cooler)
-      (mail-2 red-warmer)
-      (mail-3 magenta)
-      (mail-4 green-warmer)
-      (mail-5 cyan)
+;;;; Date mappings
+
+      (date-common yellow-cooler)
+      (date-deadline red-warmer)
+      (date-event fg-alt)
+      (date-holiday cyan-cooler)
+      (date-now fg-main)
+      (date-scheduled yellow)
+      (date-weekday cyan)
+      (date-weekend red-faint)
+
+;;;; Prose mappings
+
+      (prose-code yellow-warmer)
+      (prose-done green-cooler)
+      (prose-macro cyan-cooler)
+      (prose-metadata fg-dim)
+      (prose-metadata-value fg-alt)
+      (prose-table fg-alt)
+      (prose-tag fg-alt)
+      (prose-todo red-warmer)
+      (prose-verbatim green-cooler)
+
+;;;; Mail mappings
+
+      (mail-cite-0 yellow-warmer)
+      (mail-cite-1 green-warmer)
+      (mail-cite-2 red)
+      (mail-cite-3 yellow-cooler)
+      (mail-part green-faint)
+      (mail-recipient green-warmer)
+      (mail-subject green-cooler)
+      (mail-other yellow)
+
+;;;; Rainbow mappings
 
       (rainbow-0 yellow-warmer)
       (rainbow-1 green-warmer)
@@ -191,10 +242,28 @@
       (rainbow-6 red-cooler)
       (rainbow-7 green)
       (rainbow-8 yellow))
-    "The `ef-autumn' palette.")
+    "The `ef-autumn' palette.
+Color values have the form (COLOR-NAME HEX-VALUE) with the former
+as a symbol and the latter as a string.
 
-  (ef-themes-theme ef-autumn ef-autumn-palette)
+Semantic color mappings have the form (MAPPING-NAME COLOR-NAME)
+with both as symbols.  The latter is a color that already exists
+in the palette and is associated with a HEX-VALUE.")
+
+  (defvar ef-autumn-palette-overrides nil
+    "Overrides for `ef-autumn-palette'.
+
+Mirror the elements of the aforementioned palette, overriding
+their value.
+
+For overrides that are shared across all of the Ef themes,
+refer to `ef-themes-common-palette-overrides'.")
+
+  (ef-themes-theme ef-autumn ef-autumn-palette ef-autumn-palette-overrides)
 
   (provide-theme 'ef-autumn))
 
+;;;###theme-autoload
+(put 'ef-autumn 'theme-properties '(:background-mode dark :kind color-scheme :family ef))
+
 ;;; ef-autumn-theme.el ends here
