@@ -1,6 +1,6 @@
 ;;; ef-bio-theme.el --- Legible dark theme with green, teal, blue, purple colors -*- lexical-binding:t -*-
 
-;; Copyright (C) 2022  Free Software Foundation, Inc.
+;; Copyright (C) 2022-2023  Free Software Foundation, Inc.
 
 ;; Author: Protesilaos Stavrou <info@protesilaos.com>
 ;; Maintainer: Ef-Themes Development <~protesilaos/ef-themes@lists.sr.ht>
@@ -37,10 +37,13 @@
 (eval-and-compile
   (require 'ef-themes)
 
-  (deftheme ef-bio "Legible dark theme with green, teal, blue, purple colors.")
+  (deftheme ef-bio
+    "Legible dark theme with green, teal, blue, purple colors.")
 
   (defconst ef-bio-palette
-    '(;; Basic tones
+    '(
+;;; Basic values
+
       (bg-main      "#111111")
       (fg-main      "#cfdfd5")
       (bg-dim       "#222522")
@@ -48,10 +51,11 @@
       (bg-alt       "#303230")
       (fg-alt       "#8fcfaf")
 
-      (bg-active    "#404240")
+      (bg-active    "#505250")
       (bg-inactive  "#161916")
 
-      ;; Basic hues for foreground values
+;;; Basic hues for foreground values
+
       (red             "#ef6560")
       (red-warmer      "#f47360")
       (red-cooler      "#ff778f")
@@ -77,7 +81,8 @@
       (cyan-cooler     "#5dc0aa")
       (cyan-faint      "#7fb4cf")
 
-      ;; Basic hues for background values
+;;; Basic hues for background values
+
       (bg-red      "#bd1f30")
       (bg-green    "#20a020")
       (bg-yellow   "#845020")
@@ -92,20 +97,25 @@
       (bg-magenta-subtle  "#50105a")
       (bg-cyan-subtle     "#004065")
 
-      ;; Diffs
-      (bg-added          "#00301f")
-      (bg-added-faint    "#002110")
-      (bg-added-refine   "#03462f")
+;;; Diffs
 
-      (bg-changed        "#323200")
-      (bg-changed-faint  "#281a00")
-      (bg-changed-refine "#484800")
+      (bg-added          "#003b1f")
+      (bg-added-faint    "#002a10")
+      (bg-added-refine   "#03512f")
+      (fg-added          "#a0e0a0")
 
-      (bg-removed        "#4a1119")
-      (bg-removed-faint  "#320a0f")
+      (bg-changed        "#363300")
+      (bg-changed-faint  "#2a1f00")
+      (bg-changed-refine "#4a4a00")
+      (fg-changed        "#efef80")
+
+      (bg-removed        "#4e1119")
+      (bg-removed-faint  "#380a0f")
       (bg-removed-refine "#751a1f")
+      (fg-removed        "#ffbfbf")
+
+;;; Graphs
 
-      ;; Graphs
       (red-graph-0-bg     "#b52c2c")
       (red-graph-1-bg     "#702020")
       (green-graph-0-bg   "#4fd100")
@@ -119,18 +129,20 @@
       (cyan-graph-0-bg    "#47dfea")
       (cyan-graph-1-bg    "#00808f")
 
-      ;; Special hues
-      (bg-mode-line  "#00552f") (fg-mode-line  "#d0ffe0")
-      (bg-accent     "#b59ffa") (fg-accent     "#000000")
-      (bg-completion "#0f3c2f")
-      (bg-hover      "#4f3f9a")
-      (bg-hover-alt  "#003e5f")
-      (bg-hl-line    "#00331f")
-      (bg-region     "#3a3027")
-      (bg-paren      "#664950")
-      (bg-err        "#361400") ; check with err
-      (bg-warning    "#332800") ; check with warning
-      (bg-info       "#132b00") ; check with info
+;;; Special hues
+
+      (bg-mode-line       "#00552f")
+      (fg-mode-line       "#d0ffe0")
+      (bg-accent          "#b59ffa")
+      (bg-completion      "#0f3c2f")
+      (bg-hover           "#4f3f9a")
+      (bg-hover-secondary "#003e5f")
+      (bg-hl-line         "#00331f")
+      (bg-region          "#3a3027")
+      (bg-paren           "#664950")
+      (bg-err             "#381400") ; check with err
+      (bg-warning         "#332800") ; check with warning
+      (bg-info            "#132f00") ; check with info
 
       (border        "#525959")
       (cursor        "#35f038")
@@ -140,22 +152,31 @@
       (modeline-warning "#dfcf33")
       (modeline-info    "#7fdfff")
 
-      (underline-err     "#ff2f2f")
-      (underline-warning "#e0dc00")
-      (underline-info    "#22ff52")
+      (underline-err     "#df2f2f")
+      (underline-warning "#c0b000")
+      (underline-info    "#22b022")
+
+;;; Conditional hues
+
+      (bg-region-intense "#0f5450")
+
+;;; Mappings
+
+;;;; General mappings
 
-      ;; Mappings
       (err red)
       (warning yellow-cooler)
       (info green)
 
       (link green-cooler)
       (link-alt cyan-cooler)
-      (date cyan-cooler)
       (name green)
       (keybind green)
+      (identifier magenta-faint)
       (prompt green-warmer)
 
+;;;; Code mappings
+
       (builtin green)
       (comment yellow-faint)
       (constant blue)
@@ -166,21 +187,51 @@
       (string magenta-cooler)
       (type cyan-warmer)
       (variable blue-warmer)
-
       (rx-escape yellow-cooler) ; compare with `string'
       (rx-construct green)
 
+;;;; Accent mappings
+
       (accent-0 green-cooler)
       (accent-1 blue-warmer)
       (accent-2 magenta-warmer)
       (accent-3 green-warmer)
 
-      (mail-0 green-cooler)
-      (mail-1 blue-warmer)
-      (mail-2 green-warmer)
-      (mail-3 magenta-cooler)
-      (mail-4 green)
-      (mail-5 blue)
+;;;; Date mappings
+
+      (date-common cyan-cooler)
+      (date-deadline red-cooler)
+      (date-event fg-alt)
+      (date-holiday magenta-warmer)
+      (date-now fg-main)
+      (date-scheduled yellow-cooler)
+      (date-weekday cyan)
+      (date-weekend red-faint)
+
+;;;; Prose mappings
+
+      (prose-code blue-warmer)
+      (prose-done green)
+      (prose-macro magenta-warmer)
+      (prose-metadata fg-dim)
+      (prose-metadata-value fg-alt)
+      (prose-table fg-alt)
+      (prose-tag yellow-faint)
+      (prose-todo red)
+      (prose-verbatim green-cooler)
+
+;;;; Mail mappings
+
+      (mail-cite-0 green-cooler)
+      (mail-cite-1 blue-warmer)
+      (mail-cite-2 green-warmer)
+      (mail-cite-3 magenta-cooler)
+      (mail-part green-faint)
+      (mail-recipient green)
+      (mail-subject blue)
+      (mail-other green-warmer)
+
+;;;; Rainbow mappings
 
       (rainbow-0 green-cooler)
       (rainbow-1 green-warmer)
@@ -191,10 +242,28 @@
       (rainbow-6 blue)
       (rainbow-7 cyan)
       (rainbow-8 magenta))
-    "The `ef-bio' palette.")
+    "The `ef-bio' palette.
+Color values have the form (COLOR-NAME HEX-VALUE) with the former
+as a symbol and the latter as a string.
 
-  (ef-themes-theme ef-bio ef-bio-palette)
+Semantic color mappings have the form (MAPPING-NAME COLOR-NAME)
+with both as symbols.  The latter is a color that already exists
+in the palette and is associated with a HEX-VALUE.")
+
+  (defvar ef-bio-palette-overrides nil
+    "Overrides for `ef-bio-palette'.
+
+Mirror the elements of the aforementioned palette, overriding
+their value.
+
+For overrides that are shared across all of the Ef themes,
+refer to `ef-themes-common-palette-overrides'.")
+
+  (ef-themes-theme ef-bio ef-bio-palette ef-bio-palette-overrides)
 
   (provide-theme 'ef-bio))
 
+;;;###theme-autoload
+(put 'ef-bio 'theme-properties '(:background-mode dark :kind color-scheme :family ef))
+
 ;;; ef-bio-theme.el ends here
