@@ -1,6 +1,6 @@
 ;;; ef-dark-theme.el --- Legible dark theme with blue, magenta, cyan, purple colors -*- lexical-binding:t -*-
 
-;; Copyright (C) 2022  Free Software Foundation, Inc.
+;; Copyright (C) 2022-2023  Free Software Foundation, Inc.
 
 ;; Author: Protesilaos Stavrou <info@protesilaos.com>
 ;; Maintainer: Ef-Themes Development <~protesilaos/ef-themes@lists.sr.ht>
@@ -37,10 +37,13 @@
 (eval-and-compile
   (require 'ef-themes)
 
-  (deftheme ef-dark "Legible dark theme with blue, magenta, cyan, purple colors.")
+  (deftheme ef-dark
+    "Legible dark theme with blue, magenta, cyan, purple colors.")
 
   (defconst ef-dark-palette
-    '(;; Basic tones
+    '(
+;;; Basic values
+
       (bg-main     "#000000")
       (fg-main     "#d0d0d0")
       (bg-dim      "#1a1a1a")
@@ -48,10 +51,11 @@
       (bg-alt      "#2b2b2b")
       (fg-alt      "#89afef")
 
-      (bg-active   "#3b3b3b")
-      (bg-inactive "#0c0c0c")
+      (bg-active   "#4b4b4b")
+      (bg-inactive "#121212")
+
+;;; Basic hues for foreground values
 
-      ;; Basic hues for foreground values
       (red             "#ef6560")
       (red-warmer      "#f47360")
       (red-cooler      "#ff5a7a")
@@ -60,7 +64,7 @@
       (green-warmer    "#6aad0f")
       (green-cooler    "#00a692")
       (green-faint     "#61a06c")
-      (yellow          "#c48032")
+      (yellow          "#bf9032")
       (yellow-warmer   "#d1843f")
       (yellow-cooler   "#df8a5a")
       (yellow-faint    "#cf9f8f")
@@ -71,13 +75,14 @@
       (magenta         "#d369af")
       (magenta-warmer  "#e580ea")
       (magenta-cooler  "#af85ff")
-      (magenta-faint   "#c57faf")
+      (magenta-faint   "#c58faf")
       (cyan            "#4fbaef")
       (cyan-warmer     "#6fafff")
       (cyan-cooler     "#1dbfcf")
       (cyan-faint      "#8aa0df")
 
-      ;; Basic hues for background values
+;;; Basic hues for background values
+
       (bg-red      "#cd2f30")
       (bg-green    "#20a020")
       (bg-yellow   "#8f5040")
@@ -92,20 +97,25 @@
       (bg-magenta-subtle  "#5a105f")
       (bg-cyan-subtle     "#004065")
 
-      ;; Diffs
-      (bg-added          "#00331f")
-      (bg-added-faint    "#002410")
-      (bg-added-refine   "#03492f")
+;;; Diffs
 
-      (bg-changed        "#323200")
-      (bg-changed-faint  "#281a00")
-      (bg-changed-refine "#484800")
+      (bg-added          "#00381f")
+      (bg-added-faint    "#002910")
+      (bg-added-refine   "#034f2f")
+      (fg-added          "#a0e0a0")
 
-      (bg-removed        "#4a1119")
-      (bg-removed-faint  "#320a0f")
-      (bg-removed-refine "#751a1f")
+      (bg-changed        "#363300")
+      (bg-changed-faint  "#2a1f00")
+      (bg-changed-refine "#4a4a00")
+      (fg-changed        "#efef80")
+
+      (bg-removed        "#4f1119")
+      (bg-removed-faint  "#380a0f")
+      (bg-removed-refine "#781a1f")
+      (fg-removed        "#ffbfbf")
+
+;;; Graphs
 
-      ;; Graphs
       (red-graph-0-bg     "#b52c2c")
       (red-graph-1-bg     "#702020")
       (green-graph-0-bg   "#4fd100")
@@ -119,20 +129,22 @@
       (cyan-graph-0-bg    "#47dfea")
       (cyan-graph-1-bg    "#00808f")
 
-      ;; Special hues
-      (bg-mode-line  "#2a2a75") (fg-mode-line  "#e0e0ff")
-      (bg-accent     "#25adff") (fg-accent     "#000000")
-      (bg-completion "#0f2d4a")
-      (bg-hover      "#004a5f")
-      (bg-hover-alt  "#551f5a")
-      (bg-hl-line    "#002435")
-      (bg-region     "#2a234a")
-      (bg-paren      "#20577a")
-      (bg-err        "#330d09") ; check with err
-      (bg-warning    "#332600") ; check with warning
-      (bg-info       "#002212") ; check with info
+;;; Special hues
 
-      (border        "#4a4a5a")
+      (bg-mode-line       "#2a2a75")
+      (fg-mode-line       "#e0e0ff")
+      (bg-accent          "#25adff")
+      (bg-completion      "#0f2d4a")
+      (bg-hover           "#004a5f")
+      (bg-hover-secondary "#551f5a")
+      (bg-hl-line         "#002435")
+      (bg-region          "#2a234a")
+      (bg-paren           "#20577a")
+      (bg-err             "#360d09") ; check with err
+      (bg-warning         "#332600") ; check with warning
+      (bg-info            "#002c12") ; check with info
+
+      (border        "#4f4f5f")
       (cursor        "#ff76ff")
       (fg-intense    "#ffffff")
 
@@ -140,22 +152,31 @@
       (modeline-warning "#dfcf33")
       (modeline-info    "#2fc82f")
 
-      (underline-err     "#ff2f2f")
-      (underline-warning "#e0dc00")
-      (underline-info    "#22ff52")
+      (underline-err     "#df2f2f")
+      (underline-warning "#c0b000")
+      (underline-info    "#22b022")
+
+;;; Conditional hues
+
+      (bg-region-intense "#3a3465")
+
+;;; Mappings
+
+;;;; General mappings
 
-      ;; Mappings
       (err red-warmer)
-      (warning yellow-warmer)
+      (warning yellow)
       (info green)
 
       (link cyan)
       (link-alt magenta)
-      (date green-cooler)
       (name blue-warmer)
       (keybind blue-cooler)
+      (identifier magenta-faint)
       (prompt green-cooler)
 
+;;;; Code mappings
+
       (builtin magenta)
       (comment yellow-faint)
       (constant blue-cooler)
@@ -166,21 +187,51 @@
       (string blue-warmer)
       (type green-cooler)
       (variable cyan-cooler)
-
       (rx-escape green-warmer) ; compare with `string'
       (rx-construct red)
 
+;;;; Accent mappings
+
       (accent-0 blue)
       (accent-1 magenta-warmer)
       (accent-2 green-cooler)
       (accent-3 red)
 
-      (mail-0 blue)
-      (mail-1 magenta-warmer)
-      (mail-2 green-cooler)
-      (mail-3 yellow-cooler)
-      (mail-4 magenta-cooler)
-      (mail-5 cyan)
+;;;; Date mappings
+
+      (date-common green-cooler)
+      (date-deadline red-warmer)
+      (date-event fg-alt)
+      (date-holiday green-cooler)
+      (date-now fg-main)
+      (date-scheduled yellow)
+      (date-weekday cyan)
+      (date-weekend red-faint)
+
+;;;; Prose mappings
+
+      (prose-code magenta-warmer)
+      (prose-done green)
+      (prose-macro green-cooler)
+      (prose-metadata fg-dim)
+      (prose-metadata-value fg-alt)
+      (prose-table fg-alt)
+      (prose-tag yellow-faint)
+      (prose-todo red-warmer)
+      (prose-verbatim blue)
+
+;;;; Mail mappings
+
+      (mail-cite-0 blue)
+      (mail-cite-1 magenta-warmer)
+      (mail-cite-2 green-cooler)
+      (mail-cite-3 yellow-cooler)
+      (mail-part magenta-faint)
+      (mail-recipient blue-warmer)
+      (mail-subject blue-cooler)
+      (mail-other cyan)
+
+;;;; Rainbow mappings
 
       (rainbow-0 green-cooler)
       (rainbow-1 blue)
@@ -191,10 +242,28 @@
       (rainbow-6 red-cooler)
       (rainbow-7 green-warmer)
       (rainbow-8 yellow))
-    "The `ef-dark' palette.")
+    "The `ef-dark' palette.
+Color values have the form (COLOR-NAME HEX-VALUE) with the former
+as a symbol and the latter as a string.
 
-  (ef-themes-theme ef-dark ef-dark-palette)
+Semantic color mappings have the form (MAPPING-NAME COLOR-NAME)
+with both as symbols.  The latter is a color that already exists
+in the palette and is associated with a HEX-VALUE.")
+
+  (defvar ef-dark-palette-overrides nil
+    "Overrides for `ef-dark-palette'.
+
+Mirror the elements of the aforementioned palette, overriding
+their value.
+
+For overrides that are shared across all of the Ef themes,
+refer to `ef-themes-common-palette-overrides'.")
+
+  (ef-themes-theme ef-dark ef-dark-palette ef-dark-palette-overrides)
 
   (provide-theme 'ef-dark))
 
+;;;###theme-autoload
+(put 'ef-dark 'theme-properties '(:background-mode dark :kind color-scheme :family ef))
+
 ;;; ef-dark-theme.el ends here
