@@ -1,6 +1,6 @@
 ;;; ef-day-theme.el --- Legible light theme with warm, varied colors (yellow, red, green, purple) -*- lexical-binding:t -*-
 
-;; Copyright (C) 2022  Free Software Foundation, Inc.
+;; Copyright (C) 2022-2023  Free Software Foundation, Inc.
 
 ;; Author: Protesilaos Stavrou <info@protesilaos.com>
 ;; Maintainer: Ef-Themes Development <~protesilaos/ef-themes@lists.sr.ht>
@@ -37,21 +37,25 @@
 (eval-and-compile
   (require 'ef-themes)
 
-  (deftheme ef-day "Legible light theme with warm, varied colors (yellow, red, green, purple).")
+  (deftheme ef-day
+    "Legible light theme with warm, varied colors (yellow, red, green, purple).")
 
   (defconst ef-day-palette
-    '(;; Basic tones
+    '(
+;;; Basic values
+
       (bg-main     "#fff5ea")
       (fg-main     "#584141")
-      (bg-dim      "#f3ebdc")
+      (bg-dim      "#f2e9db")
       (fg-dim      "#63728f")
       (bg-alt      "#e9e0d8")
       (fg-alt      "#8f5f4a")
 
-      (bg-active   "#d9d0c8")
-      (bg-inactive "#f9f1e8")
+      (bg-active   "#c9c0b8")
+      (bg-inactive "#f7efe6")
+
+;;; Basic hues for foreground values
 
-      ;; Basic hues for foreground values
       (red             "#ba2d2f")
       (red-warmer      "#ce3f00")
       (red-cooler      "#cf2f4f")
@@ -77,7 +81,8 @@
       (cyan-cooler     "#0f7b8f")
       (cyan-faint      "#4f6f8f")
 
-      ;; Basic hues for background values
+;;; Basic hues for background values
+
       (bg-red      "#ff8f88")
       (bg-green    "#96df80")
       (bg-yellow   "#efbf00")
@@ -92,20 +97,25 @@
       (bg-magenta-subtle  "#fad3ff")
       (bg-cyan-subtle     "#bfefff")
 
-      ;; Diffs
+;;; Diffs
+
       (bg-added          "#ccefcf")
       (bg-added-faint    "#e0f3e0")
       (bg-added-refine   "#bae0c0")
+      (fg-added          "#005000")
 
       (bg-changed        "#ffe5b9")
       (bg-changed-faint  "#ffefc5")
       (bg-changed-refine "#ffd09f")
+      (fg-changed        "#553d00")
 
       (bg-removed        "#ffd4d8")
       (bg-removed-faint  "#ffe3e3")
       (bg-removed-refine "#ffc0ca")
+      (fg-removed        "#8f1313")
+
+;;; Graphs
 
-      ;; Graphs
       (red-graph-0-bg     "#ef7969")
       (red-graph-1-bg     "#ffaab4")
       (green-graph-0-bg   "#4faa09")
@@ -119,20 +129,22 @@
       (cyan-graph-0-bg    "#70d3f0")
       (cyan-graph-1-bg    "#afefff")
 
-      ;; Special hues
-      (bg-mode-line  "#ffaf72") (fg-mode-line  "#542f38")
-      (bg-accent     "#106246") (fg-accent     "#ffffff")
-      (bg-completion "#ffd5d3")
-      (bg-hover      "#b0e0df")
-      (bg-hover-alt  "#febccf")
-      (bg-hl-line    "#f9e2b2")
-      (bg-region     "#f0d2df")
-      (bg-paren      "#8fcfdf")
-      (bg-err        "#ffddee") ; check with err
-      (bg-warning    "#ffe0aa") ; check with warning
-      (bg-info       "#ddf5cc") ; check with info
+;;; Special hues
 
-      (border        "#cdc2bb")
+      (bg-mode-line       "#ffaf72")
+      (fg-mode-line       "#542f38")
+      (bg-accent          "#106246")
+      (bg-completion      "#ffd5d3")
+      (bg-hover           "#b0e0df")
+      (bg-hover-secondary "#febccf")
+      (bg-hl-line         "#f9e2b2")
+      (bg-region          "#f0d2df")
+      (bg-paren           "#8fcfdf")
+      (bg-err             "#ffdde5") ; check with err
+      (bg-warning         "#ffe0aa") ; check with warning
+      (bg-info            "#ddf5cc") ; check with info
+
+      (border        "#c8bdb6")
       (cursor        "#cf1f00")
       (fg-intense    "#000000")
 
@@ -144,18 +156,27 @@
       (underline-warning "#bf5f00")
       (underline-info    "#02af52")
 
-      ;; Mappings
+;;; Conditional hues
+
+      (bg-region-intense "#dfc39a")
+
+;;; Mappings
+
+;;;; General mappings
+
       (err red-warmer)
-      (warning yellow-warmer)
+      (warning yellow)
       (info green)
 
       (link cyan-warmer)
       (link-alt green-warmer)
-      (date cyan-cooler)
       (name yellow)
       (keybind red-warmer)
+      (identifier magenta-faint)
       (prompt yellow)
 
+;;;; Code mappings
+
       (builtin red-cooler)
       (comment green-faint)
       (constant red-warmer)
@@ -166,21 +187,51 @@
       (string green-warmer)
       (type green-cooler)
       (variable magenta-cooler)
-
       (rx-escape blue) ; compare with `string'
       (rx-construct magenta-warmer)
 
+;;;; Accent mappings
+
       (accent-0 red)
       (accent-1 green-cooler)
       (accent-2 yellow)
       (accent-3 magenta-warmer)
 
-      (mail-0 red)
-      (mail-1 green)
-      (mail-2 yellow)
-      (mail-3 green-cooler)
-      (mail-4 yellow-cooler)
-      (mail-5 blue)
+;;;; Date mappings
+
+      (date-common cyan-cooler)
+      (date-deadline red)
+      (date-event fg-alt)
+      (date-holiday yellow)
+      (date-now fg-main)
+      (date-scheduled yellow)
+      (date-weekday cyan)
+      (date-weekend red-faint)
+
+;;;; Prose mappings
+
+      (prose-code green-cooler)
+      (prose-done green)
+      (prose-macro yellow)
+      (prose-metadata fg-dim)
+      (prose-metadata-value fg-alt)
+      (prose-table fg-alt)
+      (prose-tag yellow-faint)
+      (prose-todo red-warmer)
+      (prose-verbatim red)
+
+;;;; Mail mappings
+
+      (mail-cite-0 red)
+      (mail-cite-1 green-cooler)
+      (mail-cite-2 yellow)
+      (mail-cite-3 cyan-warmer)
+      (mail-part red-faint)
+      (mail-recipient yellow)
+      (mail-subject red-warmer)
+      (mail-other green-warmer)
+
+;;;; Rainbow mappings
 
       (rainbow-0 yellow)
       (rainbow-1 red)
@@ -191,10 +242,28 @@
       (rainbow-6 magenta-cooler)
       (rainbow-7 red-cooler)
       (rainbow-8 green-cooler))
-    "The `ef-day' palette.")
+    "The `ef-day' palette.
+Color values have the form (COLOR-NAME HEX-VALUE) with the former
+as a symbol and the latter as a string.
 
-  (ef-themes-theme ef-day ef-day-palette)
+Semantic color mappings have the form (MAPPING-NAME COLOR-NAME)
+with both as symbols.  The latter is a color that already exists
+in the palette and is associated with a HEX-VALUE.")
+
+  (defvar ef-day-palette-overrides nil
+    "Overrides for `ef-day-palette'.
+
+Mirror the elements of the aforementioned palette, overriding
+their value.
+
+For overrides that are shared across all of the Ef themes,
+refer to `ef-themes-common-palette-overrides'.")
+
+  (ef-themes-theme ef-day ef-day-palette ef-day-palette-overrides)
 
   (provide-theme 'ef-day))
 
+;;;###theme-autoload
+(put 'ef-day 'theme-properties '(:background-mode light :kind color-scheme :family ef))
+
 ;;; ef-day-theme.el ends here
