@@ -1,6 +1,6 @@
 ;;; ef-duo-dark-theme.el --- Legible dark theme with mostly blue and orange colors -*- lexical-binding:t -*-
 
-;; Copyright (C) 2022  Free Software Foundation, Inc.
+;; Copyright (C) 2022-2023  Free Software Foundation, Inc.
 
 ;; Author: Protesilaos Stavrou <info@protesilaos.com>
 ;; Maintainer: Ef-Themes Development <~protesilaos/ef-themes@lists.sr.ht>
@@ -40,21 +40,25 @@
   ;; Most of the colors here are defined simply to preserve
   ;; compatibility with the rest of the project.  We don't actually rely
   ;; on them for anything critical.
-  (deftheme ef-duo-dark "Legible dark theme with mostly blue and orange colors.")
+  (deftheme ef-duo-dark
+    "Legible dark theme with mostly blue and orange colors.")
 
   (defconst ef-duo-dark-palette
-    '(;; Basic tones
+    '(
+;;; Basic values
+
       (bg-main     "#070019")
       (fg-main     "#d0d0d0")
-      (bg-dim      "#1c1926")
+      (bg-dim      "#1d1a26")
       (fg-dim      "#857f8f")
-      (bg-alt      "#262230")
+      (bg-alt      "#2a2739")
       (fg-alt      "#89afef")
 
-      (bg-active   "#363240")
-      (bg-inactive "#140e1c")
+      (bg-active   "#4a4759")
+      (bg-inactive "#13101f")
+
+;;; Basic hues for foreground values
 
-      ;; Basic hues for foreground values
       (red             "#ef656a")
       (red-warmer      "#f47360")
       (red-cooler      "#ef798f")
@@ -80,7 +84,8 @@
       (cyan-cooler     "#0dafdf")
       (cyan-faint      "#8aa0df")
 
-      ;; Basic hues for background values
+;;; Basic hues for background values
+
       (bg-red      "#cd2f30")
       (bg-green    "#20a020")
       (bg-yellow   "#8f5040")
@@ -95,20 +100,25 @@
       (bg-magenta-subtle  "#5a105f")
       (bg-cyan-subtle     "#004065")
 
-      ;; Diffs
+;;; Diffs
+
       (bg-added          "#002d1f")
       (bg-added-faint    "#001f18")
       (bg-added-refine   "#003b2f")
+      (fg-added          "#a0e0a0")
 
       (bg-changed        "#323200")
       (bg-changed-faint  "#2a2000")
       (bg-changed-refine "#444000")
+      (fg-changed        "#efef80")
 
       (bg-removed        "#3d091f")
       (bg-removed-faint  "#27040f")
       (bg-removed-refine "#5b0f26")
+      (fg-removed        "#ffbfbf")
+
+;;; Graphs
 
-      ;; Graphs
       (red-graph-0-bg     "#b52c2c")
       (red-graph-1-bg     "#702020")
       (green-graph-0-bg   "#4fd100")
@@ -122,18 +132,20 @@
       (cyan-graph-0-bg    "#47dfea")
       (cyan-graph-1-bg    "#00808f")
 
-      ;; Special hues
-      (bg-mode-line  "#352487") (fg-mode-line  "#dedeff")
-      (bg-accent     "#ffb250") (fg-accent     "#000000")
-      (bg-completion "#2f1a5f")
-      (bg-hover      "#664f4a")
-      (bg-hover-alt  "#264f4a")
-      (bg-hl-line    "#301a4f")
-      (bg-region     "#042a50")
-      (bg-paren      "#2f608e")
-      (bg-err        "#330d09") ; check with err
-      (bg-warning    "#332600") ; check with warning
-      (bg-info       "#002212") ; check with info
+;;; Special hues
+
+      (bg-mode-line       "#352487")
+      (fg-mode-line       "#dedeff")
+      (bg-accent          "#ffb250")
+      (bg-completion      "#2f1a5f")
+      (bg-hover           "#664f4a")
+      (bg-hover-secondary "#264f4a")
+      (bg-hl-line         "#301a4f")
+      (bg-region          "#042a50")
+      (bg-paren           "#2f608e")
+      (bg-err             "#360d09") ; check with err
+      (bg-warning         "#332600") ; check with warning
+      (bg-info            "#002d12") ; check with info
 
       (border        "#545f6f")
       (cursor        "#ef6f11")
@@ -143,22 +155,31 @@
       (modeline-warning "#dfcf00")
       (modeline-info    "#00e06f")
 
-      (underline-err     "#ff2f2f")
-      (underline-warning "#e0dc00")
-      (underline-info    "#22ff52")
+      (underline-err     "#df2f2f")
+      (underline-warning "#c0b000")
+      (underline-info    "#22b022")
+
+;;; Conditional hues
+
+      (bg-region-intense "#1f2f70")
+
+;;; Mappings
+
+;;;; General mappings
 
-      ;; Mappings
       (err red)
       (warning yellow)
       (info green)
 
       (link cyan-warmer)
       (link-alt green-cooler)
-      (date cyan-cooler)
       (name blue)
       (keybind blue-cooler)
+      (identifier red-faint)
       (prompt yellow)
 
+;;;; Code mappings
+
       (builtin cyan)
       (comment yellow-faint)
       (constant blue)
@@ -169,21 +190,51 @@
       (string yellow-cooler)
       (type blue-cooler)
       (variable magenta-cooler)
-
       (rx-escape magenta-cooler) ; compare with `string'
       (rx-construct blue)
 
+;;;; Accent mappings
+
       (accent-0 blue-warmer)
       (accent-1 yellow-warmer)
       (accent-2 green-cooler)
       (accent-3 red)
 
-      (mail-0 cyan)
-      (mail-1 yellow-cooler)
-      (mail-2 blue-warmer)
-      (mail-3 yellow)
-      (mail-4 cyan-cooler)
-      (mail-5 green-warmer)
+;;;; Date mappings
+
+      (date-common cyan-cooler)
+      (date-deadline red)
+      (date-event fg-alt)
+      (date-holiday green-cooler)
+      (date-now fg-main)
+      (date-scheduled yellow)
+      (date-weekday cyan)
+      (date-weekend red-faint)
+
+;;;; Prose mappings
+
+      (prose-code yellow-warmer)
+      (prose-done green)
+      (prose-macro green-cooler)
+      (prose-metadata fg-dim)
+      (prose-metadata-value fg-alt)
+      (prose-table fg-alt)
+      (prose-tag yellow-faint)
+      (prose-todo red)
+      (prose-verbatim blue-warmer)
+
+;;;; Mail mappings
+
+      (mail-cite-0 cyan)
+      (mail-cite-1 yellow-cooler)
+      (mail-cite-2 blue-warmer)
+      (mail-cite-3 yellow)
+      (mail-part blue-faint)
+      (mail-recipient blue)
+      (mail-subject yellow-warmer)
+      (mail-other cyan-warmer)
+
+;;;; Rainbow mappings
 
       (rainbow-0 blue)
       (rainbow-1 yellow-warmer)
@@ -194,10 +245,28 @@
       (rainbow-6 blue-cooler)
       (rainbow-7 red-cooler)
       (rainbow-8 green-cooler))
-    "The `ef-duo-dark' palette.")
+    "The `ef-duo-dark' palette.
+Color values have the form (COLOR-NAME HEX-VALUE) with the former
+as a symbol and the latter as a string.
 
-  (ef-themes-theme ef-duo-dark ef-duo-dark-palette)
+Semantic color mappings have the form (MAPPING-NAME COLOR-NAME)
+with both as symbols.  The latter is a color that already exists
+in the palette and is associated with a HEX-VALUE.")
+
+  (defvar ef-duo-dark-palette-overrides nil
+    "Overrides for `ef-duo-dark-palette'.
+
+Mirror the elements of the aforementioned palette, overriding
+their value.
+
+For overrides that are shared across all of the Ef themes,
+refer to `ef-themes-common-palette-overrides'.")
+
+  (ef-themes-theme ef-duo-dark ef-duo-dark-palette ef-duo-dark-palette-overrides)
 
   (provide-theme 'ef-duo-dark))
 
+;;;###theme-autoload
+(put 'ef-duo-dark 'theme-properties '(:background-mode dark :kind color-scheme :family ef))
+
 ;;; ef-duo-dark-theme.el ends here
