@@ -1,6 +1,6 @@
 ;;; ef-frost-theme.el --- Legible light theme with blue, cyan, teal, purple colors -*- lexical-binding:t -*-
 
-;; Copyright (C) 2022  Free Software Foundation, Inc.
+;; Copyright (C) 2022-2023  Free Software Foundation, Inc.
 
 ;; Author: Protesilaos Stavrou <info@protesilaos.com>
 ;; Maintainer: Ef-Themes Development <~protesilaos/ef-themes@lists.sr.ht>
@@ -37,10 +37,13 @@
 (eval-and-compile
   (require 'ef-themes)
 
-  (deftheme ef-frost "Legible light theme with blue, cyan, teal, purple colors.")
+  (deftheme ef-frost
+    "Legible light theme with blue, cyan, teal, purple colors.")
 
   (defconst ef-frost-palette
-    '(;; Basic tones
+    '(
+;;; Basic values
+
       (bg-main     "#fcffff")
       (fg-main     "#232323")
       (bg-dim      "#eaefef")
@@ -48,10 +51,11 @@
       (bg-alt      "#d7dbdb")
       (fg-alt      "#204f9a")
 
-      (bg-active   "#c7cbcb")
+      (bg-active   "#b5b8b8")
       (bg-inactive "#f7f9f9")
 
-      ;; Basic hues for foreground values
+;;; Basic hues for foreground values
+
       (red             "#c42d2f")
       (red-warmer      "#d03003")
       (red-cooler      "#cf2f4f")
@@ -77,7 +81,8 @@
       (cyan-cooler     "#007a85")
       (cyan-faint      "#305f9f")
 
-      ;; Basic hues for background values
+;;; Basic hues for background values
+
       (bg-red      "#ff8f88")
       (bg-green    "#8adf80")
       (bg-yellow   "#fac200")
@@ -92,20 +97,25 @@
       (bg-magenta-subtle  "#ffddff")
       (bg-cyan-subtle     "#bfefff")
 
-      ;; Diffs
+;;; Diffs
+
       (bg-added          "#c9ffea")
       (bg-added-faint    "#d7fff5")
       (bg-added-refine   "#b3efdf")
+      (fg-added          "#004840")
 
       (bg-changed        "#ffdfb9")
       (bg-changed-faint  "#ffefcb")
       (bg-changed-refine "#ffcfa0")
+      (fg-changed        "#553d00")
 
       (bg-removed        "#ffd6e0")
       (bg-removed-faint  "#ffe9e6")
       (bg-removed-refine "#f5bfc8")
+      (fg-removed        "#8f1313")
+
+;;; Graphs
 
-      ;; Graphs
       (red-graph-0-bg     "#ef7969")
       (red-graph-1-bg     "#ffaab4")
       (green-graph-0-bg   "#4faa09")
@@ -119,18 +129,20 @@
       (cyan-graph-0-bg    "#70d3f0")
       (cyan-graph-1-bg    "#afefff")
 
-      ;; Special hues
-      (bg-mode-line  "#9ad0ff") (fg-mode-line  "#051524")
-      (bg-accent     "#0000d0") (fg-accent     "#ffffff")
-      (bg-completion "#cceff5")
-      (bg-hover      "#cab5ff")
-      (bg-hover-alt  "#aae0bf")
-      (bg-hl-line    "#dff6e4")
-      (bg-region     "#d4eaf3")
-      (bg-paren      "#cab0ef")
-      (bg-err        "#ffdfda") ; check with err
-      (bg-warning    "#ffe9bf") ; check with warning
-      (bg-info       "#ccefcf") ; check with info
+;;; Special hues
+
+      (bg-mode-line       "#9ad0ff")
+      (fg-mode-line       "#051524")
+      (bg-accent          "#0000d0")
+      (bg-completion      "#cceff5")
+      (bg-hover           "#eab5ff")
+      (bg-hover-secondary "#aae0bf")
+      (bg-hl-line         "#dff6e4")
+      (bg-region          "#d4eaf3")
+      (bg-paren           "#cab0ef")
+      (bg-err             "#ffdfda") ; check with err
+      (bg-warning         "#ffe9bf") ; check with warning
+      (bg-info            "#ccefcf") ; check with info
 
       (border        "#b0b7c0")
       (cursor        "#0055bb")
@@ -144,18 +156,27 @@
       (underline-warning "#bf5f00")
       (underline-info    "#02af52")
 
-      ;; Mappings
+;;; Conditional hues
+
+      (bg-region-intense "#aadfcc")
+
+;;; Mappings
+
+;;;; General mappings
+
       (err red)
       (warning yellow-cooler)
       (info green)
 
       (link cyan)
       (link-alt magenta)
-      (date cyan-cooler)
       (name cyan-warmer)
       (keybind blue-cooler)
+      (identifier magenta-faint)
       (prompt blue)
 
+;;;; Code mappings
+
       (builtin cyan)
       (comment yellow-faint)
       (constant blue-cooler)
@@ -166,21 +187,51 @@
       (string blue-warmer)
       (type magenta-cooler)
       (variable cyan-warmer)
-
       (rx-escape yellow-cooler) ; compare with `string'
       (rx-construct red-cooler)
 
+;;;; Accent mappings
+
       (accent-0 blue-warmer)
       (accent-1 green-cooler)
       (accent-2 magenta-warmer)
       (accent-3 blue-cooler)
 
-      (mail-0 blue)
-      (mail-1 cyan-cooler)
-      (mail-2 magenta)
-      (mail-3 cyan)
-      (mail-4 cyan-warmer)
-      (mail-5 blue-cooler)
+;;;; Date mappings
+
+      (date-common cyan-cooler)
+      (date-deadline red)
+      (date-event fg-alt)
+      (date-holiday magenta-warmer)
+      (date-now fg-main)
+      (date-scheduled yellow-cooler)
+      (date-weekday cyan)
+      (date-weekend red-faint)
+
+;;;; Prose mappings
+
+      (prose-code green-cooler)
+      (prose-done green)
+      (prose-macro magenta-warmer)
+      (prose-metadata fg-dim)
+      (prose-metadata-value fg-alt)
+      (prose-table fg-alt)
+      (prose-tag yellow-faint)
+      (prose-todo red)
+      (prose-verbatim blue-warmer)
+
+;;;; Mail mappings
+
+      (mail-cite-0 blue)
+      (mail-cite-1 cyan-cooler)
+      (mail-cite-2 yellow-cooler)
+      (mail-cite-3 magenta-cooler)
+      (mail-part cyan)
+      (mail-recipient cyan-warmer)
+      (mail-subject blue-cooler)
+      (mail-other cyan)
+
+;;;; Rainbow mappings
 
       (rainbow-0 cyan-cooler)
       (rainbow-1 blue)
@@ -191,10 +242,28 @@
       (rainbow-6 green-warmer)
       (rainbow-7 magenta)
       (rainbow-8 cyan-warmer))
-    "The `ef-frost' palette.")
+    "The `ef-frost' palette.
+Color values have the form (COLOR-NAME HEX-VALUE) with the former
+as a symbol and the latter as a string.
 
-  (ef-themes-theme ef-frost ef-frost-palette)
+Semantic color mappings have the form (MAPPING-NAME COLOR-NAME)
+with both as symbols.  The latter is a color that already exists
+in the palette and is associated with a HEX-VALUE.")
+
+  (defvar ef-frost-palette-overrides nil
+    "Overrides for `ef-frost-palette'.
+
+Mirror the elements of the aforementioned palette, overriding
+their value.
+
+For overrides that are shared across all of the Ef themes,
+refer to `ef-themes-common-palette-overrides'.")
+
+  (ef-themes-theme ef-frost ef-frost-palette ef-frost-palette-overrides)
 
   (provide-theme 'ef-frost))
 
+;;;###theme-autoload
+(put 'ef-frost 'theme-properties '(:background-mode light :kind color-scheme :family ef))
+
 ;;; ef-frost-theme.el ends here
