@@ -1,6 +1,6 @@
 ;;; ef-night-theme.el --- Legible dark theme with mostly green, blue, purple colors -*- lexical-binding:t -*-
 
-;; Copyright (C) 2022  Free Software Foundation, Inc.
+;; Copyright (C) 2022-2023  Free Software Foundation, Inc.
 
 ;; Author: Protesilaos Stavrou <info@protesilaos.com>
 ;; Maintainer: Ef-Themes Development <~protesilaos/ef-themes@lists.sr.ht>
@@ -37,21 +37,25 @@
 (eval-and-compile
   (require 'ef-themes)
 
-  (deftheme ef-night "Legible dark theme with mostly green, blue, purple colors.")
+  (deftheme ef-night
+    "Legible dark theme with mostly green, blue, purple colors.")
 
   (defconst ef-night-palette
-    '(;; Basic tones
+    '(
+;;; Basic values
+
       (bg-main     "#000e17")
       (fg-main     "#afbcbf")
-      (bg-dim      "#0f1b29")
+      (bg-dim      "#1a202b")
       (fg-dim      "#70819f")
-      (bg-alt      "#1a2a2f")
+      (bg-alt      "#242e39")
       (fg-alt      "#b0a0a0")
 
-      (bg-active   "#28353f")
-      (bg-inactive "#0f121f")
+      (bg-active   "#444e59")
+      (bg-inactive "#11141f")
+
+;;; Basic hues for foreground values
 
-      ;; Basic hues for foreground values
       (red             "#ef656a")
       (red-warmer      "#f47360")
       (red-cooler      "#ef798f")
@@ -77,7 +81,8 @@
       (cyan-cooler     "#3dc0b0")
       (cyan-faint      "#92b4df")
 
-      ;; Basic hues for background values
+;;; Basic hues for background values
+
       (bg-red      "#cd2f30")
       (bg-green    "#20a020")
       (bg-yellow   "#904f30")
@@ -92,20 +97,25 @@
       (bg-magenta-subtle  "#50105a")
       (bg-cyan-subtle     "#004065")
 
-      ;; Diffs
-      (bg-added          "#002d1f")
-      (bg-added-faint    "#001f18")
-      (bg-added-refine   "#003b2f")
+;;; Diffs
 
-      (bg-changed        "#323200")
-      (bg-changed-faint  "#292000")
-      (bg-changed-refine "#484700")
+      (bg-added          "#00371f")
+      (bg-added-faint    "#002918")
+      (bg-added-refine   "#004c2f")
+      (fg-added          "#a0e0a0")
+
+      (bg-changed        "#363300")
+      (bg-changed-faint  "#2a1f00")
+      (bg-changed-refine "#4a4a00")
+      (fg-changed        "#efef80")
 
       (bg-removed        "#450f1f")
       (bg-removed-faint  "#2f060f")
       (bg-removed-refine "#641426")
+      (fg-removed        "#ffbfbf")
+
+;;; Graphs
 
-      ;; Graphs
       (red-graph-0-bg     "#b52c2c")
       (red-graph-1-bg     "#702020")
       (green-graph-0-bg   "#4fd100")
@@ -119,20 +129,22 @@
       (cyan-graph-0-bg    "#47dfea")
       (cyan-graph-1-bg    "#00808f")
 
-      ;; Special hues
-      (bg-mode-line  "#003a7f") (fg-mode-line  "#ceeeff")
-      (bg-accent     "#ff9270") (fg-accent     "#000000")
-      (bg-completion "#00314f")
-      (bg-hover      "#6f345a")
-      (bg-hover-alt  "#493737")
-      (bg-hl-line    "#002255")
-      (bg-region     "#222f40")
-      (bg-paren      "#664950")
-      (bg-err        "#331419") ; check with err
-      (bg-warning    "#332613") ; check with warning
-      (bg-info       "#00251f") ; check with info
+;;; Special hues
 
-      (border        "#34445a")
+      (bg-mode-line       "#003a7f")
+      (fg-mode-line       "#ceeeff")
+      (bg-accent          "#ff9270")
+      (bg-completion      "#00314f")
+      (bg-hover           "#6f345a")
+      (bg-hover-secondary "#493737")
+      (bg-hl-line         "#002255")
+      (bg-region          "#222f40")
+      (bg-paren           "#664950")
+      (bg-err             "#331419") ; check with err
+      (bg-warning         "#332613") ; check with warning
+      (bg-info            "#002e1f") ; check with info
+
+      (border        "#3a4a66")
       (cursor        "#00ccff")
       (fg-intense    "#ffffff")
 
@@ -140,22 +152,31 @@
       (modeline-warning "#dfcf00")
       (modeline-info    "#00e06f")
 
-      (underline-err     "#ff2f2f")
-      (underline-warning "#e0dc00")
-      (underline-info    "#22ff52")
+      (underline-err     "#df2f2f")
+      (underline-warning "#c0b000")
+      (underline-info    "#22b022")
+
+;;; Conditional hues
+
+      (bg-region-intense "#3f2f60")
+
+;;; Mappings
+
+;;;; General mappings
 
-      ;; Mappings
       (err red)
       (warning yellow-warmer)
       (info green-cooler)
 
       (link cyan-warmer)
       (link-alt magenta)
-      (date cyan)
       (name blue-warmer)
       (keybind green-cooler)
+      (identifier magenta-faint)
       (prompt cyan-cooler)
 
+;;;; Code mappings
+
       (builtin green-cooler)
       (comment yellow-faint)
       (constant magenta-cooler)
@@ -166,35 +187,83 @@
       (string blue-cooler)
       (type magenta-cooler)
       (variable cyan)
-
       (rx-escape green) ; compare with `string'
       (rx-construct magenta-warmer)
 
+;;;; Accent mappings
+
       (accent-0 blue-cooler)
       (accent-1 magenta-warmer)
       (accent-2 cyan-cooler)
       (accent-3 red-cooler)
 
-      (mail-0 blue)
-      (mail-1 magenta-warmer)
-      (mail-2 green-cooler)
-      (mail-3 yellow)
-      (mail-4 magenta-cooler)
-      (mail-5 cyan)
+;;;; Date mappings
+
+      (date-common cyan)
+      (date-deadline red)
+      (date-event fg-alt)
+      (date-holiday cyan-cooler)
+      (date-now fg-main)
+      (date-scheduled yellow)
+      (date-weekday cyan)
+      (date-weekend red-faint)
+
+;;;; Prose mappings
+
+      (prose-code magenta-warmer)
+      (prose-done green-cooler)
+      (prose-macro cyan-cooler)
+      (prose-metadata fg-dim)
+      (prose-metadata-value fg-alt)
+      (prose-table fg-alt)
+      (prose-tag fg-alt)
+      (prose-todo red)
+      (prose-verbatim blue-cooler)
+
+;;;; Mail mappings
+
+      (mail-cite-0 blue)
+      (mail-cite-1 magenta-warmer)
+      (mail-cite-2 green-cooler)
+      (mail-cite-3 yellow-cooler)
+      (mail-part cyan)
+      (mail-recipient blue-warmer)
+      (mail-subject cyan-cooler)
+      (mail-other cyan-warmer)
+
+;;;; Rainbow mappings
 
       (rainbow-0 cyan-warmer)
       (rainbow-1 magenta-cooler)
       (rainbow-2 yellow-cooler)
       (rainbow-3 blue-warmer)
-      (rainbow-4 red)
+      (rainbow-4 magenta)
       (rainbow-5 green)
-      (rainbow-6 magenta)
+      (rainbow-6 yellow)
       (rainbow-7 cyan)
-      (rainbow-8 yellow))
-    "The `ef-night' palette.")
+      (rainbow-8 green-warmer))
+    "The `ef-night' palette.
+Color values have the form (COLOR-NAME HEX-VALUE) with the former
+as a symbol and the latter as a string.
 
-  (ef-themes-theme ef-night ef-night-palette)
+Semantic color mappings have the form (MAPPING-NAME COLOR-NAME)
+with both as symbols.  The latter is a color that already exists
+in the palette and is associated with a HEX-VALUE.")
+
+  (defvar ef-night-palette-overrides nil
+    "Overrides for `ef-night-palette'.
+
+Mirror the elements of the aforementioned palette, overriding
+their value.
+
+For overrides that are shared across all of the Ef themes,
+refer to `ef-themes-common-palette-overrides'.")
+
+  (ef-themes-theme ef-night ef-night-palette ef-night-palette-overrides)
 
   (provide-theme 'ef-night))
 
+;;;###theme-autoload
+(put 'ef-night 'theme-properties '(:background-mode dark :kind color-scheme :family ef))
+
 ;;; ef-night-theme.el ends here
