@@ -1,6 +1,6 @@
 ;;; ef-summer-theme.el --- Legible light theme with magenta, purple, gold, cyan colors -*- lexical-binding:t -*-
 
-;; Copyright (C) 2022  Free Software Foundation, Inc.
+;; Copyright (C) 2022-2023  Free Software Foundation, Inc.
 
 ;; Author: Protesilaos Stavrou <info@protesilaos.com>
 ;; Maintainer: Ef-Themes Development <~protesilaos/ef-themes@lists.sr.ht>
@@ -37,21 +37,25 @@
 (eval-and-compile
   (require 'ef-themes)
 
-  (deftheme ef-summer "Legible light theme with magenta, purple, gold, cyan colors.")
+  (deftheme ef-summer
+    "Legible light theme with magenta, purple, gold, cyan colors.")
 
   (defconst ef-summer-palette
-    '(;; Basic tones
+    '(
+;;; Basic values
+
       (bg-main     "#fff2f3")
       (fg-main     "#4f4073")
-      (bg-dim      "#f3e7eb")
+      (bg-dim      "#f2e4ea")
       (fg-dim      "#786e74")
       (bg-alt      "#efd3e4")
       (fg-alt      "#af4988")
 
-      (bg-active   "#dfc3d4")
-      (bg-inactive "#f9eff0")
+      (bg-active   "#cfb3c4")
+      (bg-inactive "#f7ebee")
+
+;;; Basic hues for foreground values
 
-      ;; Basic hues for foreground values
       (red             "#d3303a")
       (red-warmer      "#e00033")
       (red-cooler      "#d50f7f")
@@ -71,13 +75,14 @@
       (magenta         "#ba35af")
       (magenta-warmer  "#cb1aaa")
       (magenta-cooler  "#8e44f3")
-      (magenta-faint   "#bf3580")
+      (magenta-faint   "#a45392")
       (cyan            "#1f6fbf")
       (cyan-warmer     "#3f6faf")
       (cyan-cooler     "#0f7b8f")
       (cyan-faint      "#5f60bf")
 
-      ;; Basic hues for background values
+;;; Basic hues for background values
+
       (bg-red      "#ff7f88")
       (bg-green    "#86df80")
       (bg-yellow   "#ffc200")
@@ -92,20 +97,25 @@
       (bg-magenta-subtle  "#ffcdff")
       (bg-cyan-subtle     "#bfeaff")
 
-      ;; Diffs
+;;; Diffs
+
       (bg-added          "#caf4da")
       (bg-added-faint    "#dff6ea")
       (bg-added-refine   "#bae9cf")
+      (fg-added          "#005000")
 
       (bg-changed        "#ffdfb9")
       (bg-changed-faint  "#ffefcb")
       (bg-changed-refine "#ffcfa0")
+      (fg-changed        "#553d00")
 
       (bg-removed        "#ffcee0")
       (bg-removed-faint  "#ffdfe6")
       (bg-removed-refine "#f5b6c8")
+      (fg-removed        "#8f1313")
+
+;;; Graphs
 
-      ;; Graphs
       (red-graph-0-bg     "#ef7969")
       (red-graph-1-bg     "#ffaab4")
       (green-graph-0-bg   "#4faa09")
@@ -119,20 +129,22 @@
       (cyan-graph-0-bg    "#70d3f0")
       (cyan-graph-1-bg    "#afefff")
 
-      ;; Special hues
-      (bg-mode-line  "#ffa4dc") (fg-mode-line  "#341f58")
-      (bg-accent     "#004f6f") (fg-accent     "#ffffff")
-      (bg-completion "#f4cfff")
-      (bg-hover      "#b4cfff")
-      (bg-hover-alt  "#aaeccf")
-      (bg-hl-line    "#ffd6e5")
-      (bg-region     "#eecfff")
-      (bg-paren      "#9fc0ef")
-      (bg-err        "#ffd0e6") ; check with err
-      (bg-warning    "#ffe5ba") ; check with warning
-      (bg-info       "#bbefda") ; check with info
+;;; Special hues
 
-      (border        "#cabfca")
+      (bg-mode-line       "#ffa4dc")
+      (fg-mode-line       "#341f58")
+      (bg-accent          "#004f6f")
+      (bg-completion      "#f4cfff")
+      (bg-hover           "#b4cfff")
+      (bg-hover-secondary "#aaeccf")
+      (bg-hl-line         "#ffd6e5")
+      (bg-region          "#eecfff")
+      (bg-paren           "#9fc0ef")
+      (bg-err             "#ffd0e6") ; check with err
+      (bg-warning         "#ffe5ba") ; check with warning
+      (bg-info            "#bbefda") ; check with info
+
+      (border        "#c6bbc6")
       (cursor        "#cf0090")
       (fg-intense    "#000000")
 
@@ -144,18 +156,27 @@
       (underline-warning "#bf5f00")
       (underline-info    "#02af52")
 
-      ;; Mappings
+;;; Conditional hues
+
+      (bg-region-intense "#caaadf")
+
+;;; Mappings
+
+;;;; General mappings
+
       (err red-warmer)
-      (warning yellow-warmer)
+      (warning yellow)
       (info green-cooler)
 
       (link blue)
       (link-alt green-cooler)
-      (date cyan-cooler)
       (name magenta-warmer)
       (keybind red-cooler)
+      (identifier magenta-faint)
       (prompt magenta-warmer)
 
+;;;; Code mappings
+
       (builtin magenta)
       (comment yellow-faint)
       (constant red-cooler)
@@ -166,21 +187,51 @@
       (string yellow-warmer)
       (type cyan-warmer)
       (variable blue-warmer)
-
       (rx-escape cyan-cooler) ; compare with `string'
       (rx-construct red-cooler)
 
+;;;; Accent mappings
+
       (accent-0 magenta-cooler)
       (accent-1 yellow)
       (accent-2 cyan-cooler)
       (accent-3 red)
 
-      (mail-0 yellow-cooler)
-      (mail-1 cyan-cooler)
-      (mail-2 magenta-warmer)
-      (mail-3 blue-warmer)
-      (mail-4 magenta-cooler)
-      (mail-5 green-warmer)
+;;;; Date mappings
+
+      (date-common cyan-cooler)
+      (date-deadline red-warmer)
+      (date-event fg-alt)
+      (date-holiday cyan-cooler)
+      (date-now fg-main)
+      (date-scheduled yellow)
+      (date-weekday cyan)
+      (date-weekend red-faint)
+
+;;;; Prose mappings
+
+      (prose-code yellow)
+      (prose-done green-cooler)
+      (prose-macro cyan-cooler)
+      (prose-metadata fg-dim)
+      (prose-metadata-value fg-alt)
+      (prose-table fg-alt)
+      (prose-tag yellow-faint)
+      (prose-todo red-warmer)
+      (prose-verbatim magenta-cooler)
+
+;;;; Mail mappings
+
+      (mail-cite-0 yellow-cooler)
+      (mail-cite-1 magenta)
+      (mail-cite-2 blue-warmer)
+      (mail-cite-3 cyan-warmer)
+      (mail-part magenta-faint)
+      (mail-recipient magenta-warmer)
+      (mail-subject magenta-cooler)
+      (mail-other magenta)
+
+;;;; Rainbow mappings
 
       (rainbow-0 magenta-warmer)
       (rainbow-1 magenta-cooler)
@@ -188,13 +239,31 @@
       (rainbow-3 cyan)
       (rainbow-4 magenta)
       (rainbow-5 blue-warmer)
-      (rainbow-6 red-warmer)
+      (rainbow-6 red-cooler)
       (rainbow-7 cyan-cooler)
       (rainbow-8 yellow-cooler))
-    "The `ef-summer' palette.")
+    "The `ef-summer' palette.
+Color values have the form (COLOR-NAME HEX-VALUE) with the former
+as a symbol and the latter as a string.
 
-  (ef-themes-theme ef-summer ef-summer-palette)
+Semantic color mappings have the form (MAPPING-NAME COLOR-NAME)
+with both as symbols.  The latter is a color that already exists
+in the palette and is associated with a HEX-VALUE.")
+
+  (defvar ef-summer-palette-overrides nil
+    "Overrides for `ef-summer-palette'.
+
+Mirror the elements of the aforementioned palette, overriding
+their value.
+
+For overrides that are shared across all of the Ef themes,
+refer to `ef-themes-common-palette-overrides'.")
+
+  (ef-themes-theme ef-summer ef-summer-palette ef-summer-palette-overrides)
 
   (provide-theme 'ef-summer))
 
+;;;###theme-autoload
+(put 'ef-summer 'theme-properties '(:background-mode light :kind color-scheme :family ef))
+
 ;;; ef-summer-theme.el ends here
