@@ -1,6 +1,6 @@
 ;;; ef-tritanopia-dark-theme.el --- Legible dark theme, optimized for blue-yellow color deficiency -*- lexical-binding:t -*-
 
-;; Copyright (C) 2022  Free Software Foundation, Inc.
+;; Copyright (C) 2022-2023  Free Software Foundation, Inc.
 
 ;; Author: Protesilaos Stavrou <info@protesilaos.com>
 ;; Maintainer: Ef-Themes Development <~protesilaos/ef-themes@lists.sr.ht>
@@ -40,21 +40,25 @@
   ;; Most of the colors here, like the blue and green hues, are defined
   ;; simply to preserve compatibility with the rest of the project.  We
   ;; don't actually rely on them for anything critical.
-  (deftheme ef-tritanopia-dark "Legible dark theme, optimized for blue-yellow color deficiency.")
+  (deftheme ef-tritanopia-dark
+    "Legible dark theme, optimized for blue-yellow color deficiency.")
 
   (defconst ef-tritanopia-dark-palette
-    '(;; Basic tones
+    '(
+;;; Basic values
+
       (bg-main      "#15050f")
       (fg-main      "#dfd0d5")
-      (bg-dim       "#221a20")
+      (bg-dim       "#282026")
       (fg-dim       "#908890")
-      (bg-alt       "#30252a")
+      (bg-alt       "#352f2f")
       (fg-alt       "#afdaef")
 
-      (bg-active    "#40353a")
-      (bg-inactive  "#1a1315")
+      (bg-active    "#554f4f")
+      (bg-inactive  "#1a1517")
+
+;;; Basic hues for foreground values
 
-      ;; Basic hues for foreground values
       (red             "#cf4f5f")
       (red-warmer      "#df4f4f")
       (red-cooler      "#d24f7f")
@@ -80,7 +84,8 @@
       (cyan-cooler     "#4fafaf")
       (cyan-faint      "#82a0af")
 
-      ;; Basic hues for background values
+;;; Basic hues for background values
+
       (bg-red      "#aa0010")
       (bg-green    "#5f806f")
       (bg-yellow   "#950f4f")
@@ -95,20 +100,25 @@
       (bg-magenta-subtle  "#5a105f")
       (bg-cyan-subtle     "#004065")
 
-      ;; Diffs
-      (bg-added          "#002d2f")
-      (bg-added-faint    "#001f28")
-      (bg-added-refine   "#003b3f")
+;;; Diffs
 
-      (bg-changed        "#30234f")
-      (bg-changed-faint  "#30143f")
-      (bg-changed-refine "#33395f")
+      (bg-added          "#002d3f")
+      (bg-added-faint    "#001f38")
+      (bg-added-refine   "#003b4f")
+      (fg-added          "#cbdfff")
 
-      (bg-removed        "#3d091f")
-      (bg-removed-faint  "#27040f")
-      (bg-removed-refine "#5b0f26")
+      (bg-changed        "#352354")
+      (bg-changed-faint  "#351444")
+      (bg-changed-refine "#383964")
+      (fg-changed        "#e3cfff")
+
+      (bg-removed        "#4d091f")
+      (bg-removed-faint  "#37040f")
+      (bg-removed-refine "#6b0f26")
+      (fg-removed        "#ffbfbf")
+
+;;; Graphs
 
-      ;; Graphs
       (red-graph-0-bg     "#b52c2c")
       (red-graph-1-bg     "#702020")
       (green-graph-0-bg   "#afd1c0")
@@ -122,20 +132,22 @@
       (cyan-graph-0-bg    "#57dfea")
       (cyan-graph-1-bg    "#00808f")
 
-      ;; Special hues
-      (bg-mode-line  "#671822") (fg-mode-line  "#ffffff")
-      (bg-accent     "#7fccee") (fg-accent     "#000000")
-      (bg-completion "#441824")
-      (bg-hover      "#00405f")
-      (bg-hover-alt  "#5e3e5b")
-      (bg-hl-line    "#3f1515")
-      (bg-region     "#202d3f")
-      (bg-paren      "#2f5f7a")
-      (bg-err        "#340f0f") ; check with err
-      (bg-warning    "#371430") ; check with warning
-      (bg-info       "#00253a") ; check with info
+;;; Special hues
 
-      (border        "#4f4f5f")
+      (bg-mode-line       "#671822")
+      (fg-mode-line       "#ffffff")
+      (bg-accent          "#7fccee")
+      (bg-completion      "#441824")
+      (bg-hover           "#00405f")
+      (bg-hover-secondary "#5e3e5b")
+      (bg-hl-line         "#3f1515")
+      (bg-region          "#202d3f")
+      (bg-paren           "#2f5f7a")
+      (bg-err             "#3a0f0f") ; check with err
+      (bg-warning         "#371430") ; check with warning
+      (bg-info            "#00253a") ; check with info
+
+      (border        "#555564")
       (cursor        "#fd3333")
       (fg-intense    "#ffffff")
 
@@ -147,18 +159,27 @@
       (underline-warning "#ffafa0")
       (underline-info    "#22ffd2")
 
-      ;; Mappings
+;;; Conditional hues
+
+      (bg-region-intense "#5f303f")
+
+;;; Mappings
+
+;;;; General mappings
+
       (err red-warmer)
       (warning magenta)
       (info cyan)
 
       (link cyan)
       (link-alt magenta-cooler)
-      (date cyan-cooler)
       (name magenta)
       (keybind red-cooler)
+      (identifier magenta-faint)
       (prompt cyan)
 
+;;;; Code mappings
+
       (builtin magenta)
       (comment red-faint)
       (constant red-cooler)
@@ -169,21 +190,51 @@
       (string cyan)
       (type cyan-warmer)
       (variable cyan-cooler)
-
       (rx-escape cyan-cooler) ; compare with `string'
       (rx-construct red)
 
+;;;; Accent mappings
+
       (accent-0 cyan)
       (accent-1 red)
       (accent-2 cyan-warmer)
       (accent-3 magenta)
 
-      (mail-0 cyan)
-      (mail-1 red-cooler)
-      (mail-2 cyan-cooler)
-      (mail-3 red-faint)
-      (mail-4 cyan-warmer)
-      (mail-5 red-warmer)
+;;;; Date mappings
+
+      (date-common cyan-cooler)
+      (date-deadline red-warmer)
+      (date-event fg-alt)
+      (date-holiday cyan-warmer)
+      (date-now fg-main)
+      (date-scheduled magenta)
+      (date-weekday cyan)
+      (date-weekend red-faint)
+
+;;;; Prose mappings
+
+      (prose-code red)
+      (prose-done cyan)
+      (prose-macro cyan-warmer)
+      (prose-metadata fg-dim)
+      (prose-metadata-value fg-alt)
+      (prose-table fg-alt)
+      (prose-tag fg-alt)
+      (prose-todo red-warmer)
+      (prose-verbatim cyan)
+
+;;;; Mail mappings
+
+      (mail-cite-0 cyan)
+      (mail-cite-1 red-cooler)
+      (mail-cite-2 cyan-cooler)
+      (mail-cite-3 red-faint)
+      (mail-part cyan-warmer)
+      (mail-recipient magenta)
+      (mail-subject red-warmer)
+      (mail-other magenta-cooler)
+
+;;;; Rainbow mappings
 
       (rainbow-0 cyan)
       (rainbow-1 red)
@@ -194,10 +245,28 @@
       (rainbow-6 cyan-faint)
       (rainbow-7 magenta-faint)
       (rainbow-8 red-faint))
-    "The `ef-tritanopia-dark' palette.")
+    "The `ef-tritanopia-dark' palette.
+Color values have the form (COLOR-NAME HEX-VALUE) with the former
+as a symbol and the latter as a string.
 
-  (ef-themes-theme ef-tritanopia-dark ef-tritanopia-dark-palette)
+Semantic color mappings have the form (MAPPING-NAME COLOR-NAME)
+with both as symbols.  The latter is a color that already exists
+in the palette and is associated with a HEX-VALUE.")
+
+  (defvar ef-tritanopia-dark-palette-overrides nil
+    "Overrides for `ef-tritanopia-dark-palette'.
+
+Mirror the elements of the aforementioned palette, overriding
+their value.
+
+For overrides that are shared across all of the Ef themes,
+refer to `ef-themes-common-palette-overrides'.")
+
+  (ef-themes-theme ef-tritanopia-dark ef-tritanopia-dark-palette ef-tritanopia-dark-palette-overrides)
 
   (provide-theme 'ef-tritanopia-dark))
 
+;;;###theme-autoload
+(put 'ef-tritanopia-dark 'theme-properties '(:background-mode dark :kind color-scheme :family ef))
+
 ;;; ef-tritanopia-dark-theme.el ends here
